@@ -1,4 +1,4 @@
-# Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2023, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::Pod;
 use strict;
 use warnings;
 
-our $VERSION = '1.33'; # VERSION
+our $VERSION = '1.40'; # VERSION
 
 use base "Devel::Cover::Criterion";
 
@@ -20,7 +20,7 @@ sub uncoverable { $_[0][2]               }
 sub covered     { $_[0][0] ? 1 : 0       }
 sub total       { 1                      }
 sub percentage  { $_[0][0] ? 100 : 0     }
-sub error       { $_[0][0] xor !$_[0][2] }
+sub error       { $_[0]->simple_error    }
 sub criterion   { "pod"                  }
 
 sub calculate_summary {
@@ -47,7 +47,7 @@ Devel::Cover::Pod - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.33
+version 1.40
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2019, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2023, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
